SerializeParams

Trait SerializeParams 

pub trait SerializeParams {
    type Key: Display;
    type Value: Display;
    type Iterator: Iterator<Item = (Self::Key, Self::Value)>;

    // Required method
    fn serialize_params(self) -> Self::Iterator;
}
Represents a value that can be serialized.

The Extras type parameter must implement this for Uri to be displayable.

Required Associated Types

type Key: Display

Parameter name.

Warning: displaying Uri will panic if the key contains = character!

type Value: Display

Parameter value.

type Iterator: Iterator<Item = (Self::Key, Self::Value)>

Iterator over key-value pairs

Required Methods

fn serialize_params(self) -> Self::Iterator

Constructs the iterator over key-value pairs.

Implementors